@@ -112,6 +112,7 @@ describe 'horizon' do
           :compress_offline             => false,
           :hypervisor_options           => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options               => {'enable_backup' => true },
+          :keystone_options             => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
           :neutron_options              => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
                                             'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
@@ -146,6 +147,14 @@ describe 'horizon' do
           'OPENSTACK_KEYSTONE_URL = "https://keystone.example.com:4682"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "SwiftOperator"',
           'OPENSTACK_SSL_NO_VERIFY = True',
+          "OPENSTACK_KEYSTONE_BACKEND = {",
+          "    'name': 'native',",
+          "    'can_edit_user': True,",
+          "    'can_edit_group': True,",
+          "    'can_edit_project': True,",
+          "    'can_edit_domain': False,",
+          "    'can_edit_role': False,",
+          "}",
           "    'can_set_mount_point': False,",
           "    'can_set_password': True,",
           "    'enable_backup': True,",
@@ -205,7 +214,7 @@ describe 'horizon' do
       it {
         is_expected.to contain_package('python-memcache').with(
           :ensure => 'present',
-          :tag    => ['openstack', 'horizon-package']
+          :tag    => ['openstack']
          )
       }
     end
@@ -422,6 +431,38 @@ describe 'horizon' do
         ])
       end
     end
+
+    context 'with websso enabled' do
+      before do
+        params.merge!({
+                        :websso_enabled => 'True',
+                        :websso_initial_choice => 'acme',
+                        :websso_choices => [
+                          ['oidc', 'OpenID Connect'],
+                          ['saml2', 'Security Assertion Markup Language'],
+                        ],
+                        :websso_idp_mapping => {
+                          'acme_oidc'  => ['acme', 'oidc'],
+                          'acme_saml2' => ['acme', 'saml2'],
+                        }
+                      })
+      end
+      it 'configures websso options' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+                                          'WEBSSO_ENABLED = True',
+                                          'WEBSSO_INITIAL_CHOICE = "acme"',
+                                          'WEBSSO_CHOICES = (',
+                                          '    ("credentials", _("Keystone Credentials")),',
+                                          '    ("oidc", _("OpenID Connect")),',
+                                          '    ("saml2", _("Security Assertion Markup Language")),',
+                                          ')',
+                                          'WEBSSO_IDP_MAPPING = {',
+                                          '    "acme_oidc": ("acme", "oidc"),',
+                                          '    "acme_saml2": ("acme", "saml2"),',
+                                          '}',
+                                        ])
+      end
+    end
   end
 
   context 'on RedHat platforms' do
